@@ -137,28 +137,43 @@ CSG_String CSG_Parameter::Get_Type_Name(void)	const
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-void CSG_Parameter::Set_UseInGUI(bool bDoUse)
+bool CSG_Parameter::Set_Collapsed(bool bOn)
 {
-	if( bDoUse )
+	if( bOn )
 	{
-		m_Constraint	&= ~PARAMETER_NOT_FOR_GUI;
+		m_Constraint |=  PARAMETER_GUI_COLLAPSED;
 	}
 	else
 	{
-		m_Constraint	|=  PARAMETER_NOT_FOR_GUI;
+		m_Constraint &= ~PARAMETER_GUI_COLLAPSED;
+	}
+
+	return( is_Collapsed() );
+}
+
+//---------------------------------------------------------
+void CSG_Parameter::Set_UseInGUI(bool bOn)
+{
+	if( bOn )
+	{
+		m_Constraint &= ~PARAMETER_NOT_FOR_GUI;
+	}
+	else
+	{
+		m_Constraint |=  PARAMETER_NOT_FOR_GUI;
 	}
 }
 
 //---------------------------------------------------------
-void CSG_Parameter::Set_UseInCMD(bool bDoUse)
+void CSG_Parameter::Set_UseInCMD(bool bOn)
 {
-	if( bDoUse )
+	if( bOn )
 	{
-		m_Constraint	&= ~PARAMETER_NOT_FOR_CMD;
+		m_Constraint &= ~PARAMETER_NOT_FOR_CMD;
 	}
 	else
 	{
-		m_Constraint	|=  PARAMETER_NOT_FOR_CMD;
+		m_Constraint |=  PARAMETER_NOT_FOR_CMD;
 	}
 }
 
@@ -1026,23 +1041,47 @@ bool CSG_Parameter::Check(bool bSilent)
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-int                             CSG_Parameter::_asInt          (void)	const	{	return( 0        );	}
-double                          CSG_Parameter::_asDouble       (void)	const	{	return( 0.       );	}
-void                          * CSG_Parameter::_asPointer      (void)	const	{	return( NULL     );	}
-const SG_Char                 * CSG_Parameter::_asString       (void)	const	{	return( m_String );	}
+int                             CSG_Parameter::_asInt            (void) const { return( 0        ); }
+double                          CSG_Parameter::_asDouble         (void) const { return( 0.       ); }
+void                          * CSG_Parameter::_asPointer        (void) const { return( NULL     ); }
+const SG_Char                 * CSG_Parameter::_asString         (void) const { return( m_String ); }
 
 //---------------------------------------------------------
-CSG_Colors                    * CSG_Parameter::asColors        (void) const {	return( Get_Type() != PARAMETER_TYPE_Colors          ? NULL : (CSG_Colors      *)asPointer() );	}
-const SG_Char                 * CSG_Parameter::asFont          (void) const {	return( Get_Type() != PARAMETER_TYPE_Font            ? NULL : (const SG_Char   *)asPointer() );	}
-CSG_Grid_System               * CSG_Parameter::asGrid_System   (void) const {	return( Get_Type() != PARAMETER_TYPE_Grid_System     ? NULL : (CSG_Grid_System *)asPointer() );	}
-CSG_Parameters                * CSG_Parameter::asParameters    (void) const {	return( Get_Type() != PARAMETER_TYPE_Parameters      ? NULL : (CSG_Parameters  *)asPointer() );	}
+CSG_Colors                    * CSG_Parameter::asColors          (void) const { return( Get_Type() != PARAMETER_TYPE_Colors      ? NULL : (CSG_Colors      *)asPointer() ); }
+const SG_Char                 * CSG_Parameter::asFont            (void) const { return( Get_Type() != PARAMETER_TYPE_Font        ? NULL : (const SG_Char   *)asPointer() ); }
+CSG_Parameters                * CSG_Parameter::asParameters      (void) const { return( Get_Type() != PARAMETER_TYPE_Parameters  ? NULL : (CSG_Parameters  *)asPointer() ); }
+CSG_Grid_System               * CSG_Parameter::asGrid_System     (void) const { return( Get_Type() != PARAMETER_TYPE_Grid_System ? NULL : (CSG_Grid_System *)asPointer() ); }
 
 //---------------------------------------------------------
-CSG_Data_Object               * CSG_Parameter::asDataObject    (void) const {	return( !is_DataObject()                             ? NULL : (CSG_Data_Object *)asPointer() );	}
-CSG_Grid                      * CSG_Parameter::asGrid          (void) const {	CSG_Data_Object	*pObject = asDataObject(); return( !pObject || pObject == DATAOBJECT_CREATE || pObject->Get_ObjectType() != SG_DATAOBJECT_TYPE_Grid       ? NULL : (CSG_Grid        *)pObject );	}
-CSG_Grids                     * CSG_Parameter::asGrids         (void) const {	CSG_Data_Object	*pObject = asDataObject(); return( !pObject || pObject == DATAOBJECT_CREATE || pObject->Get_ObjectType() != SG_DATAOBJECT_TYPE_Grids      ? NULL : (CSG_Grids       *)pObject );	}
-CSG_TIN                       * CSG_Parameter::asTIN           (void) const {	CSG_Data_Object	*pObject = asDataObject(); return( !pObject || pObject == DATAOBJECT_CREATE || pObject->Get_ObjectType() != SG_DATAOBJECT_TYPE_TIN        ? NULL : (CSG_TIN         *)pObject );	}
-CSG_PointCloud                * CSG_Parameter::asPointCloud    (void) const {	CSG_Data_Object	*pObject = asDataObject(); return( !pObject || pObject == DATAOBJECT_CREATE || pObject->Get_ObjectType() != SG_DATAOBJECT_TYPE_PointCloud ? NULL : (CSG_PointCloud  *)pObject );	}
+CSG_Grid_Resampling             CSG_Parameter::asGrid_Resampling (void) const
+{
+	int Method;
+
+	if( Get_Type() == PARAMETER_TYPE_Choice && asChoice()->Get_Data(Method) )
+	{
+		switch( Method )
+		{
+		case (int)CSG_Grid_Resampling::NearestNeighbour: return( CSG_Grid_Resampling::NearestNeighbour );
+		case (int)CSG_Grid_Resampling::Bilinear        : return( CSG_Grid_Resampling::Bilinear         );
+		case (int)CSG_Grid_Resampling::Bicubic_1       : return( CSG_Grid_Resampling::Bicubic_1        );
+		case (int)CSG_Grid_Resampling::Bicubic_2       : return( CSG_Grid_Resampling::Bicubic_2        );
+		case (int)CSG_Grid_Resampling::Mean_Nodes      : return( CSG_Grid_Resampling::Mean_Nodes       );
+		case (int)CSG_Grid_Resampling::Mean_Cells      : return( CSG_Grid_Resampling::Mean_Cells       );
+		case (int)CSG_Grid_Resampling::Minimum         : return( CSG_Grid_Resampling::Minimum          );
+		case (int)CSG_Grid_Resampling::Maximum         : return( CSG_Grid_Resampling::Maximum          );
+		case (int)CSG_Grid_Resampling::Majority        : return( CSG_Grid_Resampling::Majority         );
+		}
+	}
+
+	return( CSG_Grid_Resampling::Undefined );
+}
+
+//---------------------------------------------------------
+CSG_Data_Object               * CSG_Parameter::asDataObject    (void) const { return( !is_DataObject() ? NULL : (CSG_Data_Object *)asPointer() ); }
+CSG_Grid                      * CSG_Parameter::asGrid          (void) const { CSG_Data_Object *pObject = asDataObject(); return( !pObject || pObject == DATAOBJECT_CREATE || pObject->Get_ObjectType() != SG_DATAOBJECT_TYPE_Grid       ? NULL : (CSG_Grid       *)pObject ); }
+CSG_Grids                     * CSG_Parameter::asGrids         (void) const { CSG_Data_Object *pObject = asDataObject(); return( !pObject || pObject == DATAOBJECT_CREATE || pObject->Get_ObjectType() != SG_DATAOBJECT_TYPE_Grids      ? NULL : (CSG_Grids      *)pObject ); }
+CSG_TIN                       * CSG_Parameter::asTIN           (void) const { CSG_Data_Object *pObject = asDataObject(); return( !pObject || pObject == DATAOBJECT_CREATE || pObject->Get_ObjectType() != SG_DATAOBJECT_TYPE_TIN        ? NULL : (CSG_TIN        *)pObject ); }
+CSG_PointCloud                * CSG_Parameter::asPointCloud    (void) const { CSG_Data_Object *pObject = asDataObject(); return( !pObject || pObject == DATAOBJECT_CREATE || pObject->Get_ObjectType() != SG_DATAOBJECT_TYPE_PointCloud ? NULL : (CSG_PointCloud *)pObject ); }
 
 //---------------------------------------------------------
 CSG_Shapes                    * CSG_Parameter::asShapes        (void) const
@@ -1142,8 +1181,10 @@ bool CSG_Parameter::Assign(CSG_Parameter *pSource)
 {
 	if( pSource && Get_Type() == pSource->Get_Type() )
 	{
-		m_bEnabled	= pSource->m_bEnabled;
-		m_Default	= pSource->m_Default;
+		m_bEnabled = pSource->m_bEnabled;
+		m_Default  = pSource->m_Default;
+
+		Set_Collapsed(pSource->is_Collapsed());
 
 		if( _Assign(pSource) )
 		{
